==> nextcloud-app-bookmarks-1%3A12.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/gl.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcadores",
    "You bookmarked \"%s\"" : "Vostede engadiu «%s» aos marcadores",
    "%1$s bookmarked \"%2$s\"" : "%1$s engadiu «%2$s» aos marcadores",
    "Someone bookmarked \"%s\"" : "Vostede engadiu «%s» aos marcadores",
    "You deleted \"%s\"" : "Vostede eliminou «%s»",
    "%1$s deleted \"%2$s\"" : "%1$s eliminou «%2$s»",
    "Someone deleted \"%s\"" : "Alguén eliminou «%s»",
    "You created folder \"%s\"" : "Vostede creou o cartafol «%s»",
    "%1$s created folder \"%2$s\"" : "%1$s creou o cartafol «%2$s»",
    "Someone created folder \"%s\"" : "Alguén creou o cartafol «%s»",
    "You moved folder \"%s\"" : "Vostede moveu o cartafol «%s»",
    "%1$s moved folder \"%2$s\"" : "%1$s moveu o cartafol «%2$s»",
    "Someone moved folder \"%s\"" : "Alguén moveu o cartafol «%s»",
    "You deleted folder \"%s\"" : "Vostede eliminou o cartafol «%s»",
    "%1$s deleted folder \"%2$s\"" : "%1$s eliminou o cartafol «%2$s»",
    "Someone deleted folder \"%s\"" : "Alguén eliminou o cartafol «%s»",
    "You shared folder \"%1$s\" with %2$s" : "Vostede compartiu o cartafol «%1$s» con %2$s",
    "You shared folder \"%s\" with someone" : "Vostede compartiu o cartafol «%s» con alguén",
    "%1$s shared folder \"%2$s\" with you" : "%1$s compartiu o cartafol «%2$s» con vostede",
    "Someone shared folder \"%s\" with you" : "Alguén compartiu o cartafol «%s» con vostede",
    "You unshared folder \"%1$s\" with %2$s" : "Vostede deixou de compartir o cartafol «%1$s» con %2$s",
    "You unshared folder \"%s\" with someone" : "Vostede deixou de compartir o cartafol «%s» con alguén",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s deixou de compartir o cartafol «%2$s» con vostede",
    "Someone unshared folder \"%s\" with you" : "Alguén deixou de compartir o cartafol «%s» con vostede",
    "No file provided for import" : "Non forneceu ningún ficheiro para importar",
    "Unsupported file type for import" : "Tipo de ficheiro non admitido para importar",
    "Bookmarks shared by %s" : "Marcador compartido por %s",
    "Recent bookmarks" : "Marcadores recentes",
    "Bookmark" : "Marcador",
    "Bookmark deleted" : "Eliminouse o marcador",
    "Bookmark created" : "Creouse o marcador",
    "Bookmark moved" : "Moveuse o marcador",
    "Bookmark updated" : "Actualizouse o marcador",
    "Create bookmark" : "Crear un marcador",
    "Takes a link and adds it to your collection of bookmarks." : "Faga unha ligazón e engádaa á súa colección de marcadores",
    "A Bookmark manager for Nextcloud" : "Un xestor de marcadores para o Nextcloud",
    "Enter new title" : "Introduza un novo título",
    "Select bookmark" : "Seleccionar marcador",
    "Details" : "Detalles",
    "Rename" : "Renomear",
    "Copy link" : "Copiar a ligazón",
    "Move" : "Mover",
    "Delete" : "Eliminar",
    "Do you really want to delete this bookmark?" : "Confirma que quere eliminar este marcador?",
    "Link copied to clipboard" : "A ligazón foi copiada no portapapeis.",
    "Open all selected" : "Abrir todos os seleccionados",
    "Move selection" : "Mover a selección",
    "Edit tags of selection" : "Editar as etiquetas de selección",
    "Delete selection" : "Eliminar a selección",
    "Select all" : "Seleccionar todo",
    "Cancel selection" : "Cancelar a selección",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Seleccionados {folders} cartafoles e {bookmarks} marcadores",
    "Do you really want to delete these items?" : "Confirma que quere eliminar estes elementos?",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Seleccionado %nmarcador","Seleccionados %n marcadores"],
    "_Selected %n folder_::_Selected %n folders_" : ["%n cartafol seleccionado"," %n cartafoles seleccionados"],
    "Go back" : "Volver",
    "Select one or more tags" : "Seleccione unha ou máis etiquetas",
    "New" : "Novo",
    "New bookmark" : "Novo marcador",
    "New folder" : "Novo cartafol",
    "Sort by created date" : "Ordenar pola data de creación.",
    "RSS feed copied" : "Fonte RSS copiada",
    "Enter a link" : "Introduza unha ligazón.",
    "Enter a title" : "Introduza o título",
    "No bookmarks found" : "Non se atoparon marcadores",
    "Add a bookmark" : "Engadir un marcador",
    "Import bookmarks" : "Importar os marcadores",
    "Sync with your browser" : "Sincronizar co seu navegador",
    "Select folder" : "Cartafol seleccionado",
    "Enter folder title" : "Introduza o título do cartafol",
    "Shared by {user}" : "Compartido por {user}",
    "Rename folder" : "Renomear o cartafol",
    "Delete folder" : "Eliminar cartafol",
    "Do you really want to delete this folder?" : "Confirma que quere eliminar este cartafol?",
    "Choose folder" : "Escoller cartafol",
    "Submit" : "Enviar",
    "Cancel" : "Cancelar",
    "Deleting bookmarks" : "Eliminando os marcadores",
    "Deleting selection" : "Eliminando a selección",
    "Importing bookmarks" : "Importando os marcadores",
    "Moving selection" : "Movendo a selección",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Movendo %n cartafol e algúns marcadores","Movendo %n cartafoles e algúns marcadores"],
    "_Moving %n folder_::_Moving %n folders_" : ["Movendo %n cartafol","Movendo %n cartafoles"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Movendo %n marcador","Movendo %n marcadores"],
    "All bookmarks" : "Todos os marcadores",
    "Recent" : "Recente",
    "Shared with you" : "Compartido con vostede",
    "Files" : "Ficheiros",
    "Broken links" : "Ligazóns rachadas",
    "Untagged" : "Sen etiquetar",
    "{used} bookmarks of {available} available" : "{used} marcadores de {available} disponíbel/is",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Os marcadores de ficheiros como as fotos ou os PDF gardaranse automaticamente nos seus ficheiros do Nextcloud, para que poida atopalos incluso cando a ligazón estea fóra de liña.",
    "No bookmarks here" : "Aquí non hai marcadores. ",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Archive path" : "Ruta do arquivo",
    "Client apps" : "Aplicacións cliente ",
    "Also check out the collection of client apps that integrate with this app: " : "Consulte tamén a colección de aplicacións de clientes que se integran con esta aplicación:",
    "Install on home screen" : "Instalar na pantalla de inicio",
    "Bookmarklet" : "Miniaplicación ligada",
    "Add to {instanceName}" : "Engadir a {instanceName}",
    "Please select \"Add to home screen\" in your browser menu" : "Seleccione «Engadir na pantalla de inicio» no menú do seu navegador",
    "Title" : "Título",
    "Link" : "Ligazón",
    "Root folder" : "Cartafol raíz",
    "Tags" : "Etiquetas",
    "Select tags and create new ones" : "Seleccionar etiquetas e crear outras novas",
    "Notes" : "Notas",
    "Notes for this bookmark …" : "Notas para este marcador…",
    "Open file" : "Abrir ficheiro",
    "Owner" : "Propietario",
    "Sharing" : "Compartindo",
    "Select a user or group" : "Seleccionar un usuario ou grupo",
    "Share link" : "Compartir ligazón",
    "Copy RSS feed" : "Copiar a fonte RSS",
    "Delete link" : "Eliminar ligazón",
    "Create public link" : "Crear ligazón pública",
    "Allow editing" : "Permitir a edición",
    "Allow resharing" : "Permitir compartir",
    "Remove share" : "Retirar a compartición",
    "Projects" : "Proxectos",
    "Link copied" : "Ligazón copiada",
    "Privacy" : "Privacidade",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Os marcadores tentarán acceder ás páxinas web que engade para engadir automaticamente información sobre elas.",
    "Enable accessing and collecting information from the web pages you add" : "Activar o acceso e a recollida de información das páxinas web que engada",
    "Performance" : "Rendemento",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Nunha instalación con moitos usuarios pode ser útil restrinxir o número de marcadores por conta.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Número máximo de marcadores permitidos por conta. (0 sen límite; o predeterminado é sen límite)",
    "Previews" : "Vistas previas",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "A fin de amosar capturas de pantalla reais dos seus sitios web marcados, Marcadores pode usar un servizo de terceiros para xerar vistas previas",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Pode rexistrarse gratuitamente en screeenly.com ou configurar o seu propio servidor.",
    "Screeenly API URL" : "URL da API Screeenly",
    "Screeenly API key" : "Clave da API Screeenly",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL da API do Webshot",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Clave da API do ScreenshotMachine",
    "Pageres CLI" : "Pageres CLI",
    "Failed to save settings" : "Produciuse un fallo ao gardar os axustes",
    "Failed to load settings" : "Produciuse un fallo ao cargar os axustes",
    "This URL is already bookmarked! Overwrite?" : "Este URL xa existe como marcador! Sobrescribilo?",
    "Enter bookmark title" : "Introduza o título do marcador",
    "Enter bookmark URL" : "Introduza o URL do marcador",
    "Folder" : "Cartafol",
    "Root Folder" : "Cartafol raíz",
    "Save" : "Gardar",
    "Failed to count unavailable bookmarks" : "Produciuse un fallo ao contar os marcadores non dispoñíbeis",
    "Failed to count archived bookmarks" : "Produciuse un fallo ao contar os marcadores arquivados",
    "Failed to load bookmark" : "Produciuse un fallo ao cargar o marcador",
    "Failed to find existing bookmark" : "Produciuse un fallo ao buscar un marcador existente",
    "Failed to create bookmark" : "Produciuse un fallo ao crear o marcador",
    "Failed to save bookmark" : "Produciuse un fallo ao gardar o marcador",
    "Failed to move bookmark" : "Produciuse un fallo ao mover os marcadores",
    "Failed to delete bookmark" : "Produciuse un fallo ao eliminar os marcadores",
    "Failed to rename tag" : "Produciuse un fallo ao renomear a etiqueta",
    "Failed to load tags" : "Produciuse un fallo ao cargar as etiquetas",
    "Failed to load folders" : "Produciuse un fallo ao cargar os cartafoles",
    "Failed to delete folder" : "Produciuse un fallo ao eliminar o cartafol",
    "Failed to create folder" : "Produciuse un fallo ao crear o cartafol",
    "Failed to fetch bookmarks." : "Produciuse un fallo ao obter os marcadores",
    "Failed to change setting" : "Produciuse un fallo ao cambiar os axustes",
    "Failed to load setting {key}" : "Produciuse un fallo ao cargar o axuste {key}",
    "Failed to update share {shareId}" : "Produciuse un fallo ao actualizar a compartición {shareId}",
    "Failed to delete share {shareId}" : "Produciuse un fallo ao eliminar a compartición {shareId}",
    "Bookmarks feed" : "Fonte de marcadores"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-bookmarks-1%3A13.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/gl.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcadores",
    "You bookmarked \"%s\"" : "Vostede engadiu «%s» aos marcadores",
    "%1$s bookmarked \"%2$s\"" : "%1$s engadiu «%2$s» aos marcadores",
    "Someone bookmarked \"%s\"" : "Vostede engadiu «%s» aos marcadores",
    "You deleted \"%s\"" : "Vostede eliminou «%s»",
    "%1$s deleted \"%2$s\"" : "%1$s eliminou «%2$s»",
    "Someone deleted \"%s\"" : "Alguén eliminou «%s»",
    "You created folder \"%s\"" : "Vostede creou o cartafol «%s»",
    "%1$s created folder \"%2$s\"" : "%1$s creou o cartafol «%2$s»",
    "Someone created folder \"%s\"" : "Alguén creou o cartafol «%s»",
    "You moved folder \"%s\"" : "Vostede moveu o cartafol «%s»",
    "%1$s moved folder \"%2$s\"" : "%1$s moveu o cartafol «%2$s»",
    "Someone moved folder \"%s\"" : "Alguén moveu o cartafol «%s»",
    "You deleted folder \"%s\"" : "Vostede eliminou o cartafol «%s»",
    "%1$s deleted folder \"%2$s\"" : "%1$s eliminou o cartafol «%2$s»",
    "Someone deleted folder \"%s\"" : "Alguén eliminou o cartafol «%s»",
    "You shared folder \"%1$s\" with %2$s" : "Vostede compartiu o cartafol «%1$s» con %2$s",
    "You shared folder \"%s\" with someone" : "Vostede compartiu o cartafol «%s» con alguén",
    "%1$s shared folder \"%2$s\" with you" : "%1$s compartiu o cartafol «%2$s» con vostede",
    "Someone shared folder \"%s\" with you" : "Alguén compartiu o cartafol «%s» con vostede",
    "You unshared folder \"%1$s\" with %2$s" : "Vostede deixou de compartir o cartafol «%1$s» con %2$s",
    "You unshared folder \"%s\" with someone" : "Vostede deixou de compartir o cartafol «%s» con alguén",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s deixou de compartir o cartafol «%2$s» con vostede",
    "Someone unshared folder \"%s\" with you" : "Alguén deixou de compartir o cartafol «%s» con vostede",
    "No file provided for import" : "Non forneceu ningún ficheiro para importar",
    "Unsupported file type for import" : "Tipo de ficheiro non admitido para importar",
    "Bookmarks shared by %s" : "Marcador compartido por %s",
    "Recent bookmarks" : "Marcadores recentes",
    "Bookmark" : "Marcador",
    "Bookmark deleted" : "Eliminouse o marcador",
    "Bookmark created" : "Creouse o marcador",
    "Bookmark moved" : "Moveuse o marcador",
    "Bookmark updated" : "Actualizouse o marcador",
    "Create bookmark" : "Crear un marcador",
    "Takes a link and adds it to your collection of bookmarks." : "Faga unha ligazón e engádaa á súa colección de marcadores",
    "A Bookmark manager for Nextcloud" : "Un xestor de marcadores para o Nextcloud",
    "Enter new title" : "Introduza un novo título",
    "Select bookmark" : "Seleccionar marcador",
    "Details" : "Detalles",
    "Rename" : "Renomear",
    "Copy link" : "Copiar a ligazón",
    "Move" : "Mover",
    "Delete" : "Eliminar",
    "Do you really want to delete this bookmark?" : "Confirma que quere eliminar este marcador?",
    "Link copied to clipboard" : "A ligazón foi copiada no portapapeis.",
    "Open all selected" : "Abrir todos os seleccionados",
    "Move selection" : "Mover a selección",
    "Edit tags of selection" : "Editar as etiquetas de selección",
    "Delete selection" : "Eliminar a selección",
    "Select all" : "Seleccionar todo",
    "Cancel selection" : "Cancelar a selección",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Seleccionados {folders} cartafoles e {bookmarks} marcadores",
    "Do you really want to delete these items?" : "Confirma que quere eliminar estes elementos?",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Seleccionado %nmarcador","Seleccionados %n marcadores"],
    "_Selected %n folder_::_Selected %n folders_" : ["%n cartafol seleccionado"," %n cartafoles seleccionados"],
    "Go back" : "Volver",
    "Share folder" : "Compartir cartafol",
    "Select one or more tags" : "Seleccione unha ou máis etiquetas",
    "New" : "Novo",
    "New bookmark" : "Novo marcador",
    "New folder" : "Novo cartafol",
    "Search" : "Buscar",
    "Sort by created date" : "Ordenar pola data de creación.",
    "RSS feed copied" : "Fonte RSS copiada",
    "Enter a link" : "Introduza unha ligazón.",
    "Enter a title" : "Introduza o título",
    "No bookmarks found" : "Non se atoparon marcadores",
    "Add a bookmark" : "Engadir un marcador",
    "Import bookmarks" : "Importar os marcadores",
    "Sync with your browser" : "Sincronizar co seu navegador",
    "Select folder" : "Cartafol seleccionado",
    "Enter folder title" : "Introduza o título do cartafol",
    "Shared by {user}" : "Compartido por {user}",
    "Rename folder" : "Renomear o cartafol",
    "Delete folder" : "Eliminar cartafol",
    "Do you really want to delete this folder?" : "Confirma que quere eliminar este cartafol?",
    "Choose folder" : "Escoller cartafol",
    "Submit" : "Enviar",
    "Cancel" : "Cancelar",
    "Deleting bookmarks" : "Eliminando os marcadores",
    "Deleting selection" : "Eliminando a selección",
    "Importing bookmarks" : "Importando os marcadores",
    "Moving selection" : "Movendo a selección",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Movendo %n cartafol e algúns marcadores","Movendo %n cartafoles e algúns marcadores"],
    "_Moving %n folder_::_Moving %n folders_" : ["Movendo %n cartafol","Movendo %n cartafoles"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Movendo %n marcador","Movendo %n marcadores"],
    "All bookmarks" : "Todos os marcadores",
    "Recent" : "Recente",
    "Shared with you" : "Compartido con vostede",
    "Files" : "Ficheiros",
    "Broken links" : "Ligazóns rachadas",
    "Untagged" : "Sen etiquetar",
    "{used} bookmarks of {available} available" : "{used} marcadores de {available} disponíbel/is",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Os marcadores de ficheiros como as fotos ou os PDF gardaranse automaticamente nos seus ficheiros do Nextcloud, para que poida atopalos incluso cando a ligazón estea fóra de liña.",
    "No bookmarks here" : "Aquí non hai marcadores. ",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Archive path" : "Ruta do arquivo",
    "Client apps" : "Aplicacións cliente ",
    "Also check out the collection of client apps that integrate with this app: " : "Consulte tamén a colección de aplicacións de clientes que se integran con esta aplicación:",
    "Install on home screen" : "Instalar na pantalla de inicio",
    "Bookmarklet" : "Miniaplicación ligada",
    "Add to {instanceName}" : "Engadir a {instanceName}",
    "Please select \"Add to home screen\" in your browser menu" : "Seleccione «Engadir na pantalla de inicio» no menú do seu navegador",
    "Title" : "Título",
    "Link" : "Ligazón",
    "Root folder" : "Cartafol raíz",
    "Tags" : "Etiquetas",
    "Select tags and create new ones" : "Seleccionar etiquetas e crear outras novas",
    "Notes" : "Notas",
    "Notes for this bookmark …" : "Notas para este marcador…",
    "Download file" : "Descargar ficheiros",
    "Owner" : "Propietario",
    "Sharing" : "Compartindo",
    "Select a user or group" : "Seleccionar un usuario ou grupo",
    "Share link" : "Compartir ligazón",
    "Copy RSS feed" : "Copiar a fonte RSS",
    "Delete link" : "Eliminar ligazón",
    "Create public link" : "Crear ligazón pública",
    "Allow editing" : "Permitir a edición",
    "Allow resharing" : "Permitir compartir",
    "Remove share" : "Retirar a compartición",
    "Link copied" : "Ligazón copiada",
    "Privacy" : "Privacidade",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Os marcadores tentarán acceder ás páxinas web que engade para engadir automaticamente información sobre elas.",
    "Enable accessing and collecting information from the web pages you add" : "Activar o acceso e a recollida de información das páxinas web que engada",
    "Performance" : "Rendemento",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Nunha instalación con moitos usuarios pode ser útil restrinxir o número de marcadores por conta.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Número máximo de marcadores permitidos por conta. (0 sen límite; o predeterminado é sen límite)",
    "Previews" : "Vistas previas",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "A fin de amosar capturas de pantalla reais dos seus sitios web marcados, Marcadores pode usar un servizo de terceiros para xerar vistas previas",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Pode rexistrarse gratuitamente en screeenly.com ou configurar o seu propio servidor.",
    "Screeenly API URL" : "URL da API Screeenly",
    "Screeenly API key" : "Clave da API Screeenly",
    "Webshot" : "Webshot",
    "Webshot API URL" : "URL da API do Webshot",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "Clave da API do ScreenshotMachine",
    "Pageres CLI" : "Pageres CLI",
    "Failed to save settings" : "Produciuse un fallo ao gardar os axustes",
    "Failed to load settings" : "Produciuse un fallo ao cargar os axustes",
    "This URL is already bookmarked! Overwrite?" : "Este URL xa existe como marcador! Sobrescribilo?",
    "Enter bookmark title" : "Introduza o título do marcador",
    "Enter bookmark URL" : "Introduza o URL do marcador",
    "Folder" : "Cartafol",
    "Root Folder" : "Cartafol raíz",
    "Save" : "Gardar",
    "Failed to count unavailable bookmarks" : "Produciuse un fallo ao contar os marcadores non dispoñíbeis",
    "Failed to count archived bookmarks" : "Produciuse un fallo ao contar os marcadores arquivados",
    "Failed to load bookmark" : "Produciuse un fallo ao cargar o marcador",
    "Failed to find existing bookmark" : "Produciuse un fallo ao buscar un marcador existente",
    "Failed to create bookmark" : "Produciuse un fallo ao crear o marcador",
    "Failed to save bookmark" : "Produciuse un fallo ao gardar o marcador",
    "Failed to move bookmark" : "Produciuse un fallo ao mover os marcadores",
    "Failed to delete bookmark" : "Produciuse un fallo ao eliminar os marcadores",
    "Failed to rename tag" : "Produciuse un fallo ao renomear a etiqueta",
    "Failed to load tags" : "Produciuse un fallo ao cargar as etiquetas",
    "Failed to load folders" : "Produciuse un fallo ao cargar os cartafoles",
    "Failed to delete folder" : "Produciuse un fallo ao eliminar o cartafol",
    "Failed to create folder" : "Produciuse un fallo ao crear o cartafol",
    "Failed to fetch bookmarks." : "Produciuse un fallo ao obter os marcadores",
    "Failed to change setting" : "Produciuse un fallo ao cambiar os axustes",
    "Failed to load setting {key}" : "Produciuse un fallo ao cargar o axuste {key}",
    "Failed to update share {shareId}" : "Produciuse un fallo ao actualizar a compartición {shareId}",
    "Failed to delete share {shareId}" : "Produciuse un fallo ao eliminar a compartición {shareId}",
    "Bookmarks feed" : "Fonte de marcadores"
},
"nplurals=2; plural=(n != 1);");
